@@ -1,4 +1,4 @@
-#! /usr/bin/env python
+#! /usr/bin/env python3
 """Unit tests for smartcard.CardConnection
 
 This test case can be executed individually, or with all other test cases
@@ -27,7 +27,6 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
 
 
-from __future__ import print_function
 import unittest
 import string
 
@@ -48,7 +47,13 @@ except ImportError:
 from smartcard.Exceptions import CardConnectionException, NoCardException
 from smartcard.System import readers
 from smartcard.CardConnection import CardConnection
-from smartcard.scard import resourceManagerSubType
+from smartcard.scard import (
+        resourceManagerSubType,
+        SCARD_SHARE_EXCLUSIVE,
+        SCARD_LEAVE_CARD,
+        SCARD_RESET_CARD,
+        SCARD_UNPOWER_CARD
+)
 
 
 class testcase_CardConnection(unittest.TestCase):
@@ -181,6 +186,61 @@ class testcase_CardConnection(unittest.TestCase):
                 self.assertRaises(NoCardException, cc.connect)
         cc.disconnect()
 
+    def testcase_CardReconnectProtocol(self):
+        """Test .reconnect()"""
+        for reader in readers():
+            cc = reader.createConnection()
+            if [] != expectedATRinReader[str(reader)]:
+                cc.connect(
+                    CardConnection.T0_protocol | CardConnection.T1_protocol)
+
+                #  reconnect in T=1 when a T=0 card (GPK 8K) shall fail
+                self.assertRaises(CardConnectionException,
+                    cc.reconnect, protocol=CardConnection.T1_protocol)
+                cc.disconnect()
+            else:
+                self.assertRaises(NoCardException, cc.connect)
+
+    def testcase_CardReconnectMode(self):
+        """Test .reconnect()"""
+        for reader in readers():
+            cc = reader.createConnection()
+            if [] != expectedATRinReader[str(reader)]:
+                cc.connect(
+                    CardConnection.T0_protocol | CardConnection.T1_protocol)
+
+                #  reconnect in exclusive mode should fail
+                self.assertRaises(CardConnectionException,
+                    cc.reconnect, mode=SCARD_SHARE_EXCLUSIVE)
+                cc.disconnect()
+            else:
+                self.assertRaises(NoCardException, cc.connect)
+
+    def testcase_CardReconnectDisposition(self):
+        """Test .reconnect()"""
+        for reader in readers():
+            cc = reader.createConnection()
+            if [] != expectedATRinReader[str(reader)]:
+                cc.connect(
+                    CardConnection.T0_protocol | CardConnection.T1_protocol)
+                cc.reconnect(disposition=SCARD_LEAVE_CARD)
+                cc.reconnect(disposition=SCARD_RESET_CARD)
+                cc.reconnect(disposition=SCARD_UNPOWER_CARD)
+                cc.disconnect()
+            else:
+                self.assertRaises(NoCardException, cc.connect)
+
+    def testcase_CardReconnectNoConnect(self):
+        """Test .reconnect()"""
+        for reader in readers():
+            cc = reader.createConnection()
+            if [] != expectedATRinReader[str(reader)]:
+                #  reconnect without connect first shall fail
+                self.assertRaises(CardConnectionException,
+                    cc.reconnect)
+            else:
+                self.assertRaises(NoCardException, cc.connect)
+
 
 def suite():
     suite1 = unittest.makeSuite(testcase_CardConnection)
