@@ -2,7 +2,7 @@
 
 __author__ = "gemalto http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -23,8 +23,9 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
 
 
-class SimpleSCardAppEventObserver:
-    """This interface defines the event handlers called by the SimpleSCardApp."""
+class SimpleSCardAppEventObserver(object):
+    """This interface defines the event handlers
+    called by the SimpleSCardApp."""
 
     def __init__(self):
         self.selectedcard = None
@@ -32,25 +33,31 @@ class SimpleSCardAppEventObserver:
 
     # callbacks from SimpleCardAppFrame controls
     def OnActivateCard(self, card):
-        """Called when a card is activated in the reader tree control or toolbar."""
+        """Called when a card is activated in the reader
+        tree control or toolbar."""
         self.selectedcard = card
 
     def OnActivateReader(self, reader):
-        """Called when a reader is activated in the reader tree control or toolbar."""
+        """Called when a reader is activated in the reader
+        tree control or toolbar."""
         self.selectedreader = reader
 
     def OnDeactivateCard(self, card):
-        """Called when a card is deactivated in the reader tree control or toolbar."""
+        """Called when a card is deactivated in the reader
+        tree control or toolbar."""
         pass
 
     def OnDeselectCard(self, card):
-        """Called when a card is selected in the reader tree control or toolbar."""
+        """Called when a card is selected in the reader
+        tree control or toolbar."""
         self.selectedcard = None
 
     def OnSelectCard(self, card):
-        """Called when a card is selected in the reader tree control or toolbar."""
+        """Called when a card is selected in the reader
+        tree control or toolbar."""
         self.selectedcard = card
 
     def OnSelectReader(self, reader):
-        """Called when a reader is selected in the reader tree control or toolbar."""
+        """Called when a reader is selected in the reader
+        tree control or toolbar."""
         self.selectedreader = reader
